summaryrefslogtreecommitdiffstats
path: root/juk/cache.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/cache.h')
-rw-r--r--juk/cache.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/juk/cache.h b/juk/cache.h
index 09f6906d..6d67f1fd 100644
--- a/juk/cache.h
+++ b/juk/cache.h
@@ -23,7 +23,7 @@ class Tag;
class Playlist;
class PlaylistCollection;
-typedef QValueList<Playlist *> PlaylistList;
+typedef TQValueList<Playlist *> PlaylistList;
class Cache : public FileHandleHash
{
@@ -45,15 +45,15 @@ private:
};
/**
* A simple QDataStream subclass that has an extra field to indicate the cache
* version.
*/
class CacheDataStream : public QDataStream
{
public:
- CacheDataStream(QIODevice *d) : QDataStream(d), m_cacheVersion(0) {}
- CacheDataStream(QByteArray a, int mode) : QDataStream(a, mode), m_cacheVersion(0) {}
+ CacheDataStream(TQIODevice *d) : TQDataStream(d), m_cacheVersion(0) {}
+ CacheDataStream(TQByteArray a, int mode) : TQDataStream(a, mode), m_cacheVersion(0) {}
virtual ~CacheDataStream() {}
@@ -45,15 +45,15 @@ private:
};
/**
- * A simple QDataStream subclass that has an extra field to indicate the cache
+ * A simple TQDataStream subclass that has an extra field to indicate the cache
* version.
*/